@@ -67,7 +67,7 @@ class Wiki:
 
 			x = requests.get(url, timeout=5)
 			data = json.loads(x.text)
-			if not data['pages']:
+			if 'pages' not in data or not data['pages']:
 				return False
 
 			if str(addr) not in data['pages']:
@@ -111,6 +111,7 @@ class Page:
 		self.title = data['title']
 		self.key = data['key']
 		self.html_url = data['html_url']
+		self.redirected = False
 
 		self.get_content()
 
@@ -124,7 +125,7 @@ class Page:
 
 		'''
 
-		url = f"https://{self.options['lang']}.wikipedia.org/w/api.php?action=query&format=json&titles={self.title}&prop=info|extracts|links&explaintext&inprop=url&redirects=1"
+		url = f"https://{self.options['lang']}.wikipedia.org/w/api.php?action=query&format=json&titles={encode(self.title)}&prop=info|extracts|links&explaintext&inprop=url&redirects=1"
 
 		# Request API
 		x = requests.get(url, timeout=5)
@@ -135,6 +136,7 @@ class Page:
 			return False
 
 		if 'redirects' in data['query']:
+			self.redirected = True
 			self.redirects = data['query']['redirects']
 
 		pages = data['query']['pages']
@@ -165,7 +167,7 @@ class Page:
 
 		'''
 
-		url = f"https://{self.options['lang']}.wikipedia.org/w/api.php?format=json&action=query&redirects=1&titles={self.key}&prop=extracts&explaintext&exintro"
+		url = f"https://{self.options['lang']}.wikipedia.org/w/api.php?format=json&action=query&redirects=1&titles={encode(self.title)}&prop=extracts&explaintext&exintro"
 
 		# Request API
 		x = requests.get(url, timeout=5)
